<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="da_DK">
<context>
    <name>BlackoutWidget</name>
    <message>
        <source>Click to Return to Application</source>
        <translation>Klik for at gå tilbage til applikationen</translation>
    </message>
</context>
<context>
    <name>DownloadDialog</name>
    <message>
        <source>Downloads</source>
        <translation>Downloads</translation>
    </message>
    <message>
        <source>Clean Up</source>
        <translation>Ryd</translation>
    </message>
    <message>
        <source>0 Items</source>
        <translation>O enheder</translation>
    </message>
</context>
<context>
    <name>DownloadItem</name>
    <message>
        <source>Form</source>
        <translation>Form</translation>
    </message>
    <message>
        <source>Filename</source>
        <translation>Filnavn</translation>
    </message>
    <message>
        <source>Try Again</source>
        <translation>Prøv igen</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Stop</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Åbn</translation>
    </message>
</context>
<context>
    <name>IntranetPodcastPublishingDialog</name>
    <message>
        <source>Publish Podcast to YouTube</source>
        <translation>Udgiv podcast på YouTube</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Titel</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Beskrivelse</translation>
    </message>
    <message>
        <source>Author</source>
        <translation>Forfatter</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Board</source>
        <translation>Tavle</translation>
    </message>
    <message>
        <source>Web</source>
        <translation>Web</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>Dokumenter</translation>
    </message>
    <message>
        <source>Stylus</source>
        <translation>Pen</translation>
    </message>
    <message>
        <source>Ctrl+T</source>
        <translation>Ctrl+T</translation>
    </message>
    <message>
        <source>Backgrounds</source>
        <translation>Baggrunde</translation>
    </message>
    <message>
        <source>Change Background</source>
        <translation>Skift baggrund</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>Fortryd</translation>
    </message>
    <message>
        <source>Ctrl+Z</source>
        <translation>Ctrl+Z</translation>
    </message>
    <message>
        <source>Redo</source>
        <translation>Annuller Fortryd</translation>
    </message>
    <message>
        <source>Ctrl+Y</source>
        <translation>Ctrl+Y</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>Forrige</translation>
    </message>
    <message>
        <source>Previous Page</source>
        <translation>Forrige side</translation>
    </message>
    <message>
        <source>PgUp</source>
        <translation>Side op</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Næste</translation>
    </message>
    <message>
        <source>Next Page</source>
        <translation>Næste side</translation>
    </message>
    <message>
        <source>PgDown</source>
        <translation>Side ned</translation>
    </message>
    <message>
        <source>Manage Documents</source>
        <translation>Administrer dokumenter</translation>
    </message>
    <message>
        <source>Ctrl+D</source>
        <translation>Ctrl+D</translation>
    </message>
    <message>
        <source>Web Browsing</source>
        <translation>Webbrowsing</translation>
    </message>
    <message>
        <source>Ctrl+W</source>
        <translation>Ctrl+W</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Linje</translation>
    </message>
    <message>
        <source>Small Line</source>
        <translation>Lille linje</translation>
    </message>
    <message>
        <source>Medium Line</source>
        <translation>Mellem linje</translation>
    </message>
    <message>
        <source>Large Line</source>
        <translation>Stor line</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Afslut</translation>
    </message>
    <message>
        <source>Eraser</source>
        <translation>Viskelæder</translation>
    </message>
    <message>
        <source>Smalle Eraser</source>
        <translation type="vanished">Lille viskelæder</translation>
    </message>
    <message>
        <source>Medium Eraser</source>
        <translation>Mellem viskelæder</translation>
    </message>
    <message>
        <source>Large Eraser</source>
        <translation>Stort viskelæder</translation>
    </message>
    <message>
        <source>Color</source>
        <translation type="vanished">Farve</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>Tilbage</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Venstre</translation>
    </message>
    <message>
        <source>Forward</source>
        <translation>Fremad</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Højre</translation>
    </message>
    <message>
        <source>Reload</source>
        <translation>Genindlæs</translation>
    </message>
    <message>
        <source>Reload Current Page</source>
        <translation>Genindlæs aktuel side</translation>
    </message>
    <message>
        <source>Home</source>
        <translation>Hjem</translation>
    </message>
    <message>
        <source>Load Home Page</source>
        <translation>Indlæs Hjem-siden</translation>
    </message>
    <message>
        <source>Bookmarks</source>
        <translation>Bogmærker</translation>
    </message>
    <message>
        <source>Show Bookmarks</source>
        <translation>Vis bogmærker</translation>
    </message>
    <message>
        <source>Bookmark</source>
        <translation>Bogmærke</translation>
    </message>
    <message>
        <source>Add Bookmark</source>
        <translation>Tilføj bogmærke</translation>
    </message>
    <message>
        <source>Display Board</source>
        <translation>Vis tavle</translation>
    </message>
    <message>
        <source>Ctrl+B</source>
        <translation>Ctrl+B</translation>
    </message>
    <message>
        <source>Erase</source>
        <translation>Slet</translation>
    </message>
    <message>
        <source>Erase Content</source>
        <translation>Slet indhold</translation>
    </message>
    <message>
        <source>Preferences</source>
        <translation>Indstillinger</translation>
    </message>
    <message>
        <source>Display Preferences</source>
        <translation>Vis Indstillinger</translation>
    </message>
    <message>
        <source>Library</source>
        <translation>Bibliotek</translation>
    </message>
    <message>
        <source>Show Library</source>
        <translation>Vis Bibliotek</translation>
    </message>
    <message>
        <source>Ctrl+L</source>
        <translation>Ctrl?l</translation>
    </message>
    <message>
        <source>Show Desktop</source>
        <translation>Vis Skrivebord</translation>
    </message>
    <message>
        <source>Show Computer Desktop</source>
        <translation>Vis computerens skrivebord</translation>
    </message>
    <message>
        <source>Ctrl+Shift+H</source>
        <translation>Ctrl+Shift+H</translation>
    </message>
    <message>
        <source>Bigger</source>
        <translation>Større</translation>
    </message>
    <message>
        <source>Zoom In</source>
        <translation>Zoom ind</translation>
    </message>
    <message>
        <source>Ctrl++</source>
        <translation>Ctrl++</translation>
    </message>
    <message>
        <source>Smaller</source>
        <translation>Mindre</translation>
    </message>
    <message>
        <source>Zoom Out</source>
        <translation>Zoom ud</translation>
    </message>
    <message>
        <source>Ctrl+-</source>
        <translation>Ctrl+-</translation>
    </message>
    <message>
        <source>New Folder</source>
        <translation>Ny mappe</translation>
    </message>
    <message>
        <source>Create a New Folder</source>
        <translation>Opret en ny mappe</translation>
    </message>
    <message>
        <source>New Document</source>
        <translation>Nyt dokument</translation>
    </message>
    <message>
        <source>Create a New Document</source>
        <translation>Opret et nyt dokument</translation>
    </message>
    <message>
        <source>Import</source>
        <translation>Importer</translation>
    </message>
    <message>
        <source>Import a Document</source>
        <translation>Importer et dokument</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Eksporter</translation>
    </message>
    <message>
        <source>Export a Document</source>
        <translation>Eksporter et dokument</translation>
    </message>
    <message>
        <source>Open in Board</source>
        <translation>Åbn i tavle</translation>
    </message>
    <message>
        <source>Open Page in Board</source>
        <translation>Åbn side i tavle</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <source>Duplicate</source>
        <translation>Dubler</translation>
    </message>
    <message>
        <source>Duplicate Selected Content</source>
        <translation>Dubler udvalgt indhold</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Slet</translation>
    </message>
    <message>
        <source>Delete Selected Content</source>
        <translation>Slet udvalgt indhold</translation>
    </message>
    <message>
        <source>Del</source>
        <translation>Del</translation>
    </message>
    <message>
        <source>Add to Working Document</source>
        <translation>Tilføj til arbejdsdokument</translation>
    </message>
    <message>
        <source>Add Selected Content to Open Document</source>
        <translation>Tilføj udvalgt indhold til åbent dokument</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Tilføj</translation>
    </message>
    <message>
        <source>Add Content to Document</source>
        <translation>Tilføj inhold til dokument</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Omdøb</translation>
    </message>
    <message>
        <source>Rename Content</source>
        <translation>Omdøb indhold</translation>
    </message>
    <message>
        <source>Tools</source>
        <translation>Værktøjer</translation>
    </message>
    <message>
        <source>Display Tools</source>
        <translation>Vis Værktøjer</translation>
    </message>
    <message>
        <source>Multi Screen</source>
        <translation>Flere skærme</translation>
    </message>
    <message>
        <source>Wide Size (16/9)</source>
        <translation>Bred størrelse (16/9)</translation>
    </message>
    <message>
        <source>Use Document Wide Size (16/9)</source>
        <translation>Brug dokument i bred størrelse (16/9)</translation>
    </message>
    <message>
        <source>Regular Size (4/3)</source>
        <translation>Almindelig størrelse (4/3)</translation>
    </message>
    <message>
        <source>Use Document Regular Size (4/3)</source>
        <translation>Brug dokument i almindelig størrelse (4/3)</translation>
    </message>
    <message>
        <source>Custom Size</source>
        <translation>Brugerdefineret størrelse</translation>
    </message>
    <message>
        <source>Use Custom Document Size</source>
        <translation>Brug brugerdefineret dokumentstørrelse</translation>
    </message>
    <message>
        <source>Stop Loading</source>
        <translation>Stop indlæsning</translation>
    </message>
    <message>
        <source>Stop Loading Web Page</source>
        <translation>Stop indlæsning af hjemmeside</translation>
    </message>
    <message>
        <source>Cut</source>
        <translation>Klip</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopier</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>Sæt ind</translation>
    </message>
    <message>
        <source>Sleep</source>
        <translation>Dvale</translation>
    </message>
    <message>
        <source>Put Presentation to Sleep</source>
        <translation>Sæt præsentation i dvale</translation>
    </message>
    <message>
        <source>Virtual Keyboard</source>
        <translation>Virtuelt tastatur</translation>
    </message>
    <message>
        <source>Display Virtual Keyboard</source>
        <translation>Vis virtuel tastatur</translation>
    </message>
    <message>
        <source>Plain Light Background</source>
        <translation>Almindelig lys baggrund</translation>
    </message>
    <message>
        <source>Light</source>
        <translation>Lys</translation>
    </message>
    <message>
        <source>Grid Light Background</source>
        <translation>Gitter lys baggrund</translation>
    </message>
    <message>
        <source>Plain Dark Background</source>
        <translation>Almindelig mørk baggrund</translation>
    </message>
    <message>
        <source>Dark</source>
        <translation>Mørk</translation>
    </message>
    <message>
        <source>Grid Dark Background</source>
        <translation>Gitter mørk baggrund</translation>
    </message>
    <message>
        <source>Podcast</source>
        <translation>Podcast</translation>
    </message>
    <message>
        <source>Record Presentation to Video</source>
        <translation>Optag præsentation til video</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>Optag</translation>
    </message>
    <message>
        <source>Start Screen Recording</source>
        <translation>Start optagelse af skærm</translation>
    </message>
    <message>
        <source>Erase Items</source>
        <translation>Slet enheder</translation>
    </message>
    <message>
        <source>Erase All Items</source>
        <translation>Slet alle enheder</translation>
    </message>
    <message>
        <source>Erase Annotations</source>
        <translation>Slet bemærkninger</translation>
    </message>
    <message>
        <source>Erase All Annotations</source>
        <translation>Slet alle bemærkninger</translation>
    </message>
    <message>
        <source>Clear Page</source>
        <translation>Ryd side</translation>
    </message>
    <message>
        <source>Clear All Elements</source>
        <translation>Ryd alle elementer</translation>
    </message>
    <message>
        <source>Pen</source>
        <translation>Pen</translation>
    </message>
    <message>
        <source>Annotate Document</source>
        <translation>Tilføj bemærkning til dokument</translation>
    </message>
    <message>
        <source>Ctrl+I</source>
        <translation>Ctrl+I</translation>
    </message>
    <message>
        <source>Erase Annotation</source>
        <translation>Slet bemærkning</translation>
    </message>
    <message>
        <source>Ctrl+E</source>
        <translation>Ctrl+E</translation>
    </message>
    <message>
        <source>Marker</source>
        <translation>Markør</translation>
    </message>
    <message>
        <source>Highlight </source>
        <translation>Fremhæv</translation>
    </message>
    <message>
        <source>Ctrl+M</source>
        <translation>Ctrl+M</translation>
    </message>
    <message>
        <source>Selector</source>
        <translation>Udvælgelsesværktøj</translation>
    </message>
    <message>
        <source>Select And Modify Objects</source>
        <translation>Vælg og ændr objekter</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <source>Hand</source>
        <translation>Hånd</translation>
    </message>
    <message>
        <source>Scroll Page</source>
        <translation>Rul ned på side</translation>
    </message>
    <message>
        <source>Laser Pointer</source>
        <translation>Laserpil</translation>
    </message>
    <message>
        <source>Virtual Laser Pointer</source>
        <translation>Virtuel laserpil</translation>
    </message>
    <message>
        <source>Ctrl+G</source>
        <translation>Ctrl+G</translation>
    </message>
    <message>
        <source>Draw Lines</source>
        <translation>Tegn linjer</translation>
    </message>
    <message>
        <source>Ctrl+J</source>
        <translation>Ctrl+J</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Tekst</translation>
    </message>
    <message>
        <source>Write Text</source>
        <translation>Skriv tekst</translation>
    </message>
    <message>
        <source>Ctrl+K</source>
        <translation>Ctrl+K</translation>
    </message>
    <message>
        <source>Capture</source>
        <translation>Skærmklip</translation>
    </message>
    <message>
        <source>Capture Part of the Screen</source>
        <translation>Klip dele af skærmen</translation>
    </message>
    <message>
        <source>Add To Current Page</source>
        <translation>Tilføj til nuværende side</translation>
    </message>
    <message>
        <source>Add Item To Current Page</source>
        <translation>Tilføj enhed til nuværende side</translation>
    </message>
    <message>
        <source>Add To New Page</source>
        <translation>Tilføj til ny side</translation>
    </message>
    <message>
        <source>Add Item To New Page</source>
        <translation>Tilføj enhed til ny side</translation>
    </message>
    <message>
        <source>Add To Library</source>
        <translation>Tilføj til bibliotek</translation>
    </message>
    <message>
        <source>Add Item To Library</source>
        <translation>Tilføj enhed til bibliotek</translation>
    </message>
    <message>
        <source>Pages</source>
        <translation>Sider</translation>
    </message>
    <message>
        <source>Create a New Page</source>
        <translation>Opret en ny side</translation>
    </message>
    <message>
        <source>New Page</source>
        <translation>Ny side</translation>
    </message>
    <message>
        <source>Duplicate Page</source>
        <translation>Dubler side</translation>
    </message>
    <message>
        <source>Duplicate the Current Page</source>
        <translation>Dubler nuværende side</translation>
    </message>
    <message>
        <source>Import Page</source>
        <translation>Importer side</translation>
    </message>
    <message>
        <source>Import an External Page</source>
        <translation>Importer en ekstern side</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pause</translation>
    </message>
    <message>
        <source>Pause Podcast Recording</source>
        <translation>Sæt podcastoptagelse på pause</translation>
    </message>
    <message>
        <source>Podcast Config</source>
        <translation>Konfigurering af podcast</translation>
    </message>
    <message>
        <source>Configure Podcast Recording</source>
        <translation>Konfigurer podcast-optagelse</translation>
    </message>
    <message>
        <source>Flash Trap</source>
        <translation type="vanished">Flash Trap</translation>
    </message>
    <message>
        <source>Trap Flash Content</source>
        <translation type="vanished">Opsaml Flash-indhold</translation>
    </message>
    <message>
        <source>Web Trap</source>
        <translation>Web Trap</translation>
    </message>
    <message>
        <source>Trap Web Content</source>
        <translation>Opsaml Web-indhold</translation>
    </message>
    <message>
        <source>Custom Capture</source>
        <translation>Brugerdefineret Skærmklip</translation>
    </message>
    <message>
        <source>Window Capture</source>
        <translation>Skærmklip af vindue</translation>
    </message>
    <message>
        <source>Capture a Window</source>
        <translation>Klip en del af vinduet</translation>
    </message>
    <message>
        <source>Embed Web Content</source>
        <translation>Indlejring af web-indhold</translation>
    </message>
    <message>
        <source>Capture Embeddable Web Content</source>
        <translation>Klip web-indhold som kan indlejres</translation>
    </message>
    <message>
        <source>Show on Display</source>
        <translation>Vis på displayet</translation>
    </message>
    <message>
        <source>Show Main Screen on Display Screen</source>
        <translation>Vis hovedskærm på displaysskærmen</translation>
    </message>
    <message>
        <source>Erase all Annotations</source>
        <translation>Slet alle bemærkninger</translation>
    </message>
    <message>
        <source>eduMedia</source>
        <translation>eduMedia</translation>
    </message>
    <message>
        <source>Import eduMedia simulation</source>
        <translation>Importer eduMedia-simulering</translation>
    </message>
    <message>
        <source>Check Update</source>
        <translation>Kontroller opdatering</translation>
    </message>
    <message>
        <source>Ctrl+H</source>
        <translation>ECtrl+H</translation>
    </message>
    <message>
        <source>OpenBoard</source>
        <translation>OpenBoard</translation>
    </message>
    <message>
        <source>Quit OpenBoard</source>
        <translation>Forlad OpenBoard</translation>
    </message>
    <message>
        <source>Hide OpenBoard</source>
        <translation>Skjul OpenBoard</translation>
    </message>
    <message>
        <source>Hide OpenBoard Application</source>
        <translation>Skjul programmet OpenBoard</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Afspil</translation>
    </message>
    <message>
        <source>Interact with items</source>
        <translation>Interagér med elementer</translation>
    </message>
    <message>
        <source>Erase Background</source>
        <translation>Slet baggrund</translation>
    </message>
    <message>
        <source>Remove the backgound</source>
        <translation>Fjern baggrunden</translation>
    </message>
    <message>
        <source>Ruled Light Background</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ruled Dark Background</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open Tutorial</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open the tutorial web page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reset grid size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Small Eraser</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Color 1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Color 2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Color 3</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Color 4</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Color 5</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Draw intermediate grid lines</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Capture Web Content</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PasswordDialog</name>
    <message>
        <source>Authentication Required</source>
        <translation>Godkendelse påkrævet</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Brugernavn:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Adgangskode:</translation>
    </message>
</context>
<context>
    <name>ProxyDialog</name>
    <message>
        <source>Proxy Authentication</source>
        <translation>Godkendelse af Proxy</translation>
    </message>
    <message>
        <source>Connect to Proxy</source>
        <translation>Forbind til Proxy</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Brugernavn:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Adgangskode:</translation>
    </message>
    <message>
        <source>Save username and password for future use</source>
        <translation>Gem brugernavn og adgangskode</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Element ID = </source>
        <translation>Element-ID = </translation>
    </message>
    <message>
        <source>Content is not supported in destination format.</source>
        <translation>Indholdet understøttes ikke i destinationsformatet.</translation>
    </message>
    <message>
        <source>Remove Page</source>
        <translation>Fjern side</translation>
    </message>
    <message>
        <source>Are you sure you want to remove 1 page from the selected document &apos;%0&apos;?</source>
        <translation>Er du sikker på, at du vil fjerne 1 side fra det valgte dokument&apos;%0&apos;?</translation>
    </message>
    <message>
        <source>Loading scene (%1/%2)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Moving cached scenes (%1/%2)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBApplication</name>
    <message>
        <source>Page Size</source>
        <translation>Sidestørrelse</translation>
    </message>
    <message>
        <source>Podcast</source>
        <translation>Podcast</translation>
    </message>
    <message>
        <source>Cannot open your UBX file directly. Please import it in Documents mode instead</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBApplicationController</name>
    <message>
        <source>Web</source>
        <translation>Web</translation>
    </message>
    <message>
        <source>New update available, would you go to the web page ?</source>
        <translation>Der er en ny opdatering tilgængelig, ønsker du at gå til opdateringens hjemmeside?</translation>
    </message>
    <message>
        <source>No update available</source>
        <translation>Der er ingen tilgængelige opdateringer</translation>
    </message>
    <message>
        <source>Update available</source>
        <translation>Opdatering er tilgængelig</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>Opdatering</translation>
    </message>
</context>
<context>
    <name>UBBackgroundPalette</name>
    <message>
        <source>Grid size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Draw intermediate grid lines</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBBoardController</name>
    <message>
        <source>Downloading content %1 failed</source>
        <translation>Download af indhold %1 mislykket</translation>
    </message>
    <message>
        <source>Download finished</source>
        <translation>Download gennemført</translation>
    </message>
    <message>
        <source>Unknown tool type %1</source>
        <translation>Ukendt værktøjstype %1</translation>
    </message>
    <message>
        <source>Unknown content type %1</source>
        <translation>Ukendt indholdtstype %1</translation>
    </message>
    <message>
        <source>Add Item</source>
        <translation>Tilføj enhed</translation>
    </message>
    <message>
        <source>All Supported (%1)</source>
        <translation>Alle understøttede (%1)</translation>
    </message>
    <message>
        <source>Delete page %1 from document</source>
        <translation type="vanished">Slet side %1 fra dokumentet</translation>
    </message>
    <message>
        <source>Page %1 deleted</source>
        <translation>Side %1 er slettet</translation>
    </message>
    <message>
        <source>Add file operation failed: file copying error</source>
        <translation>Tilføjelse af fil mislykkedes: Fejl ved kopiering af fil</translation>
    </message>
    <message>
        <source>Group</source>
        <translation>Gruppér</translation>
    </message>
    <message>
        <source>Ungroup</source>
        <translation>Opdel gruppe</translation>
    </message>
    <message>
        <source>Saving document...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Document has just been saved...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Deleting page %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Color</source>
        <translation type="unfinished">Farve</translation>
    </message>
</context>
<context>
    <name>UBBoardPaletteManager</name>
    <message>
        <source>Error Adding Image to Library</source>
        <translation>Fejl under tilføjelse af billede til bibliotek</translation>
    </message>
    <message>
        <source>CapturedImage</source>
        <translation>HentetBillede</translation>
    </message>
</context>
<context>
    <name>UBBoardThumbnailsView</name>
    <message>
        <source>Loading page (%1/%2)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBCachePropertiesWidget</name>
    <message>
        <source>Cache Properties</source>
        <translation>Egenskaber for cache</translation>
    </message>
    <message>
        <source>Color:</source>
        <translation>Farve:</translation>
    </message>
    <message>
        <source>Shape:</source>
        <translation>Form:</translation>
    </message>
    <message>
        <source>Size:</source>
        <translation>Størrelse:</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Luk</translation>
    </message>
</context>
<context>
    <name>UBDesktopPalette</name>
    <message>
        <source>Capture Part of the Screen</source>
        <translation>Klip del af skærmen</translation>
    </message>
    <message>
        <source>Capture the Screen</source>
        <translation>Klip skærmen</translation>
    </message>
    <message>
        <source>Show the stylus palette</source>
        <translation>Vis penpaletten</translation>
    </message>
    <message>
        <source>Show Board on Secondary Screen</source>
        <translation>Vis tavle på sekundær skærm</translation>
    </message>
    <message>
        <source>Show Desktop on Secondary Screen</source>
        <translation>Vis skrivebord på sekundær skærm</translation>
    </message>
    <message>
        <source>Show OpenBoard</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBDocumentController</name>
    <message>
        <source>New Folder</source>
        <translation>Ny mappe</translation>
    </message>
    <message>
        <source>Page %1</source>
        <translation>Side %1</translation>
    </message>
    <message>
        <source>Add Folder of Images</source>
        <translation>Tilføj mappe med billeder</translation>
    </message>
    <message>
        <source>Add Images</source>
        <translation>Tilføj billeder</translation>
    </message>
    <message>
        <source>Add Pages from File</source>
        <translation>Tilføj sider fra fil</translation>
    </message>
    <message>
        <source>Duplicating Document %1</source>
        <translation>Dubler dokument %1</translation>
    </message>
    <message>
        <source>Document %1 copied</source>
        <translation>Dokument %1 kopieret</translation>
    </message>
    <message>
        <source>Remove Page</source>
        <translation type="vanished">Fjern side</translation>
    </message>
    <message>
        <source>Remove Document</source>
        <translation type="vanished">Fjern dokument</translation>
    </message>
    <message>
        <source>Are you sure you want to remove the document &apos;%1&apos;?</source>
        <translation type="vanished">Er du sikker på, at du ønsker at fjerne dokumentet &apos;%1&apos;?</translation>
    </message>
    <message>
        <source>Empty Trash</source>
        <translation type="vanished">Tøm papirkurv</translation>
    </message>
    <message>
        <source>Are you sure you want to empty trash?</source>
        <translation type="vanished">Er du sikker på, at du ønsker at tømme papirkurven?</translation>
    </message>
    <message>
        <source>Emptying trash</source>
        <translation type="vanished">Tømmer papirkurv</translation>
    </message>
    <message>
        <source>Emptied trash</source>
        <translation type="vanished">Tømt papirkurv</translation>
    </message>
    <message>
        <source>Remove Folder</source>
        <translation type="vanished">Fjern mappe</translation>
    </message>
    <message>
        <source>Are you sure you want to remove the folder &apos;%1&apos; and all its content?</source>
        <translation type="vanished">Er du sikker på, at du ønsker at fjerne mappen &apos; %1&apos; og hele dens indhold?</translation>
    </message>
    <message>
        <source>No document selected!</source>
        <translation type="vanished">Der er ikke valgt noget dokument!</translation>
    </message>
    <message>
        <source>Open Supported File</source>
        <translation>Åbn understøttet fil</translation>
    </message>
    <message>
        <source>Importing file %1...</source>
        <translation>Importerer fil %1...</translation>
    </message>
    <message>
        <source>Failed to import file ... </source>
        <translation>Kunne ikke importere fil ... </translation>
    </message>
    <message>
        <source>Import all Images from Folder</source>
        <translation>Importer alle billeder fra mappe</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Slet</translation>
    </message>
    <message>
        <source>Empty</source>
        <translation>Tøm</translation>
    </message>
    <message>
        <source>Trash</source>
        <translation>Papirkurv</translation>
    </message>
    <message>
        <source>Open Document</source>
        <translation>Åbn dokument</translation>
    </message>
    <message>
        <source>Add all Images to Document</source>
        <translation>Tilføj alle billeder til dokument</translation>
    </message>
    <message>
        <source>All Images (%1)</source>
        <translation>Alle billeder ( %1)</translation>
    </message>
    <message>
        <source>Selection does not contain any image files!</source>
        <translation>Udsnittet indeholder ikke nogen billedfiler!</translation>
    </message>
    <message numerus="yes">
        <source>Are you sure you want to remove %n page(s) from the selected document &apos;%1&apos;?</source>
        <translation type="vanished">
            <numerusform>Er du sikker på, at du vil fjerne %n side fra det valgte dokument &apos;%1&apos;?</numerusform>
            <numerusform>Er du sikker på, at du vil fjerne %n sider fra det valgte dokument &apos;%1&apos;?</numerusform>
        </translation>
    </message>
    <message>
        <source>Folder does not contain any image files</source>
        <translation>Mappen indeholder ikke nogen billedfiler</translation>
    </message>
    <message>
        <source>Untitled Documents</source>
        <translation>Unavngivne dokumenter</translation>
    </message>
    <message numerus="yes">
        <source>duplicated %1 page</source>
        <comment>duplicated %1 pages</comment>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>Remove Item</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are you sure you want to remove the selected item(s) ?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The document &apos;%1&apos; has been generated with a newer version of OpenBoard (%2). By opening it, you may lose some information. Do you want to proceed?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Title page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Refreshing Document Thumbnails View (%1/%2)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBDocumentManager</name>
    <message>
        <source>images</source>
        <translation>Billeder</translation>
    </message>
    <message>
        <source>videos</source>
        <translation>videoer</translation>
    </message>
    <message>
        <source>objects</source>
        <translation>objekter</translation>
    </message>
    <message>
        <source>widgets</source>
        <translation>widgets</translation>
    </message>
    <message>
        <source>All supported files (*.%1)</source>
        <translation>alle understøttede filer (*%1)</translation>
    </message>
    <message>
        <source>File %1 saved</source>
        <translation>Fil %1 gemt</translation>
    </message>
    <message>
        <source>Inserting page %1 of %2</source>
        <translation>Indsætter side %1 af %2</translation>
    </message>
    <message>
        <source>Import successful.</source>
        <translation>Import gennemført.</translation>
    </message>
    <message>
        <source>Import of file %1 successful.</source>
        <translation>Import af fil %1 gennemført.</translation>
    </message>
    <message>
        <source>Importing file %1</source>
        <translation>Importer fil %1</translation>
    </message>
</context>
<context>
    <name>UBDocumentNavigator</name>
    <message>
        <source>Page %0</source>
        <translation>Side %0</translation>
    </message>
    <message>
        <source>Generating thumbnails for board (%1/%2)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBDocumentPublisher</name>
    <message>
        <source>Export failed.</source>
        <translation type="obsolete">Eksport mislykkedes.</translation>
    </message>
</context>
<context>
    <name>UBDocumentReplaceDialog</name>
    <message>
        <source>Accept</source>
        <translation type="unfinished">Accepter</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">Annuller</translation>
    </message>
    <message>
        <source>Replace</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The name %1 is allready used.
Keeping this name will replace the document.
Providing a new name will create a new document.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBDocumentTreeModel</name>
    <message>
        <source>Trash</source>
        <translation type="unfinished">Papirkurv</translation>
    </message>
    <message numerus="yes">
        <source>%1 pages copied</source>
        <translation type="unfinished">
            <numerusform>%1 side kopieret</numerusform>
            <numerusform>%1 sider kopieret</numerusform>
        </translation>
    </message>
    <message>
        <source>My documents</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBDocumentTreeView</name>
    <message numerus="yes">
        <source>%1 pages copied</source>
        <translation type="unfinished">
            <numerusform>%1 side kopieret</numerusform>
            <numerusform>%1 sider kopieret</numerusform>
        </translation>
    </message>
    <message>
        <source>Remove Item</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are you sure you want to remove the selected item(s) ?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copying page %1/%2</source>
        <translation type="unfinished">Kopierer side %1/%2</translation>
    </message>
</context>
<context>
    <name>UBDocumentTreeWidget</name>
    <message>
        <source>%1 (copy)</source>
        <translation type="vanished">%1 (kopier)</translation>
    </message>
    <message>
        <source>Copying page %1/%2</source>
        <translation type="vanished">Kopierer side %1/%2</translation>
    </message>
    <message numerus="yes">
        <source>%1 pages copied</source>
        <translation type="vanished">
            <numerusform>%1 side kopieret</numerusform>
            <numerusform>%1 sider kopieret</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>UBDownloadWidget</name>
    <message>
        <source>Downloading files</source>
        <translation>Downloader filer</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuller</translation>
    </message>
</context>
<context>
    <name>UBDraggableThumbnail</name>
    <message>
        <source>Page %0</source>
        <translation type="unfinished">Side %0</translation>
    </message>
</context>
<context>
    <name>UBDraggableThumbnailView</name>
    <message>
        <source>Page %0</source>
        <translation type="unfinished">Side %0</translation>
    </message>
</context>
<context>
    <name>UBExportAdaptor</name>
    <message>
        <source>Warnings during export was appeared</source>
        <translation>Advarsler under eksportering blev vist</translation>
    </message>
    <message>
        <source>Exporting document...</source>
        <translation type="unfinished">Eksporterer dokument...</translation>
    </message>
    <message>
        <source>Export successful.</source>
        <translation type="unfinished">Eksport gennemført.</translation>
    </message>
    <message>
        <source>Export failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to export to the selected location. You do not have the permissions necessary to save the file.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export failed: location not writable</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBExportCFF</name>
    <message>
        <source>Export to IWB</source>
        <translation>Eksporter til IWB</translation>
    </message>
    <message>
        <source>Export as IWB File</source>
        <translation>Eksporter som IWB-fil</translation>
    </message>
    <message>
        <source>Exporting document...</source>
        <translation>Eksporterer dokument...</translation>
    </message>
    <message>
        <source>Export successful.</source>
        <translation>Eksport gennemført.</translation>
    </message>
    <message>
        <source>Export failed.</source>
        <translation>Eksport mislykkedes.</translation>
    </message>
</context>
<context>
    <name>UBExportDocument</name>
    <message>
        <source>Page</source>
        <translation>Side</translation>
    </message>
    <message>
        <source>Export as UBZ File</source>
        <translation>Eksporter som UBZ-fil</translation>
    </message>
    <message>
        <source>Exporting document...</source>
        <translation type="vanished">Eksporterer dokument...</translation>
    </message>
    <message>
        <source>Export successful.</source>
        <translation type="vanished">Eksport gennemført.</translation>
    </message>
    <message>
        <source>Exporting %1 %2 of %3</source>
        <translation>Eksporterer %1 %2 af %3</translation>
    </message>
    <message>
        <source>Export to OpenBoard Format</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBExportDocumentSetAdaptor</name>
    <message>
        <source>Exporting document...</source>
        <translation type="unfinished">Eksporterer dokument...</translation>
    </message>
    <message>
        <source>Export successful.</source>
        <translation type="unfinished">Eksport gennemført.</translation>
    </message>
    <message>
        <source>Export failed.</source>
        <translation type="unfinished">Eksport mislykkedes.</translation>
    </message>
    <message>
        <source>Failed to export...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export as UBX File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export to OpenBoard UBX Format</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBExportFullPDF</name>
    <message>
        <source>Export as PDF File</source>
        <translation>Eksporter som PDF-fil</translation>
    </message>
    <message>
        <source>Exporting document...</source>
        <translation type="vanished">Eksporterer dokument...</translation>
    </message>
    <message>
        <source>Export successful.</source>
        <translation type="vanished">Eksport gennemført.</translation>
    </message>
    <message>
        <source>Export to PDF</source>
        <translation>Eksport til PDF</translation>
    </message>
</context>
<context>
    <name>UBExportPDF</name>
    <message>
        <source>Export as PDF File</source>
        <translation>Eksport som PDF-fil</translation>
    </message>
    <message>
        <source>Exporting document...</source>
        <translation type="vanished">Eksporterer dokument...</translation>
    </message>
    <message>
        <source>Export successful.</source>
        <translation type="vanished">Eksport gennemført.</translation>
    </message>
    <message>
        <source>Exporting page %1 of %2</source>
        <translation>Eksporterer side %1 af %2</translation>
    </message>
    <message>
        <source>Export to PDF</source>
        <translation>Eksport til PDF</translation>
    </message>
</context>
<context>
    <name>UBExportWeb</name>
    <message>
        <source>Page</source>
        <translation>Side</translation>
    </message>
    <message>
        <source>Export as Web data</source>
        <translation>Eksporter som webdata</translation>
    </message>
    <message>
        <source>Exporting document...</source>
        <translation>Eksporterer dokument...</translation>
    </message>
    <message>
        <source>Export successful.</source>
        <translation>Eksport gennemført.</translation>
    </message>
    <message>
        <source>Export failed.</source>
        <translation>Eksport mislykkedes.</translation>
    </message>
    <message>
        <source>Export to Web Browser</source>
        <translation>Eksport til webbrowser</translation>
    </message>
</context>
<context>
    <name>UBFeatureProperties</name>
    <message>
        <source>Add to page</source>
        <translation>Tilføj til side</translation>
    </message>
    <message>
        <source>Set as background</source>
        <translation type="vanished">Brug som baggrund</translation>
    </message>
    <message>
        <source>Add to library</source>
        <translation>Tilføj til bibliotek</translation>
    </message>
    <message>
        <source>Object informations</source>
        <translation>Objektinformationer</translation>
    </message>
</context>
<context>
    <name>UBFeaturesActionBar</name>
    <message>
        <source>Add to favorites</source>
        <translation>Tilføj til favoritter</translation>
    </message>
    <message>
        <source>Share</source>
        <translation>Del</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Søg</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Slet</translation>
    </message>
    <message>
        <source>Back to folder</source>
        <translation>Tilbage til mappe</translation>
    </message>
    <message>
        <source>Remove from favorites</source>
        <translation>Fjern fra favoritter</translation>
    </message>
    <message>
        <source>Create new folder</source>
        <translation>Opret ny mappe</translation>
    </message>
    <message>
        <source>Rescan file system</source>
        <translation>Gennemsøg filsystem igen</translation>
    </message>
</context>
<context>
    <name>UBFeaturesController</name>
    <message>
        <source>ImportedImage</source>
        <translation>ImporteretBillede</translation>
    </message>
    <message>
        <source>Audios</source>
        <translation>Lydfiler</translation>
    </message>
    <message>
        <source>Movies</source>
        <translation>Film</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Billeder</translation>
    </message>
    <message>
        <source>Animations</source>
        <translation type="vanished">Animationer</translation>
    </message>
    <message>
        <source>Interactivities</source>
        <translation>Interaktiviteter</translation>
    </message>
    <message>
        <source>Applications</source>
        <translation>Applikationer</translation>
    </message>
    <message>
        <source>Shapes</source>
        <translation>Former</translation>
    </message>
    <message>
        <source>Favorites</source>
        <translation>Favoritter</translation>
    </message>
    <message>
        <source>Web search</source>
        <translation>Websøgning</translation>
    </message>
    <message>
        <source>Trash</source>
        <translation>Papirkurv</translation>
    </message>
</context>
<context>
    <name>UBFeaturesNewFolderDialog</name>
    <message>
        <source>Accept</source>
        <translation>Accepter</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuller</translation>
    </message>
    <message>
        <source>Enter a new folder name</source>
        <translation>Indtast et nyt mappenavn</translation>
    </message>
</context>
<context>
    <name>UBFeaturesProgressInfo</name>
    <message>
        <source>Loading </source>
        <translation>Indlæser</translation>
    </message>
</context>
<context>
    <name>UBGraphicsGroupContainerItemDelegate</name>
    <message>
        <source>Locked</source>
        <translation>Låst</translation>
    </message>
    <message>
        <source>Visible on Extended Screen</source>
        <translation>Synlig på udvidet skærm</translation>
    </message>
</context>
<context>
    <name>UBGraphicsItemDelegate</name>
    <message>
        <source>Locked</source>
        <translation>Låst</translation>
    </message>
    <message>
        <source>Visible on Extended Screen</source>
        <translation>Synlig på udvidet skærm</translation>
    </message>
    <message>
        <source>Go to Content Source</source>
        <translation>Gå til indholdskilde</translation>
    </message>
    <message>
        <source>Set as background</source>
        <translation type="unfinished">Brug som baggrund</translation>
    </message>
</context>
<context>
    <name>UBGraphicsMediaItem</name>
    <message>
        <source>Media resource couldn&apos;t be resolved</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unsupported media format</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Media playback service not found</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Media error: </source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBGraphicsTextItem</name>
    <message>
        <source>&lt;Type Text Here&gt;</source>
        <translation>&lt;Indtast tekst her&gt;</translation>
    </message>
</context>
<context>
    <name>UBGraphicsTextItemDelegate</name>
    <message>
        <source>Text Color</source>
        <translation>Tekstfarve</translation>
    </message>
    <message>
        <source>Editable</source>
        <translation>Kan redigeres</translation>
    </message>
</context>
<context>
    <name>UBGraphicsW3CWidgetItem</name>
    <message>
        <source>Web</source>
        <translation>Web</translation>
    </message>
</context>
<context>
    <name>UBGraphicsWidgetItem</name>
    <message>
        <source>Loading ...</source>
        <translation>Indlæser...</translation>
    </message>
</context>
<context>
    <name>UBGraphicsWidgetItemDelegate</name>
    <message>
        <source>Frozen</source>
        <translation>Frossen</translation>
    </message>
    <message>
        <source>Transform as Tool </source>
        <translation>Transformer som værktøj</translation>
    </message>
</context>
<context>
    <name>UBImportCFF</name>
    <message>
        <source>Common File Format (</source>
        <translation>Almindelig filformat (</translation>
    </message>
    <message>
        <source>Importing file %1...</source>
        <translation>Importerer fil %1...</translation>
    </message>
    <message>
        <source>Import of file %1 failed.</source>
        <translation>Import af fil %1 mislykkedes.</translation>
    </message>
    <message>
        <source>Import successful.</source>
        <translation>Import gennemført.</translation>
    </message>
    <message>
        <source>Import failed.</source>
        <translation>Import mislykkedes.</translation>
    </message>
</context>
<context>
    <name>UBImportDocument</name>
    <message>
        <source>Importing file %1...</source>
        <translation>Importerer fil %1...</translation>
    </message>
    <message>
        <source>Import successful.</source>
        <translation>Import gennemført.</translation>
    </message>
    <message>
        <source>Import of file %1 failed.</source>
        <translation>Import af fil %1 mislykkedes.</translation>
    </message>
    <message>
        <source>OpenBoard (*.ubz)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBImportDocumentSetAdaptor</name>
    <message>
        <source>Openboard (set of documents) (*.ubx)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBImportImage</name>
    <message>
        <source>Image Format (</source>
        <translation>Billedformat (</translation>
    </message>
</context>
<context>
    <name>UBImportPDF</name>
    <message>
        <source>Portable Document Format (*.pdf)</source>
        <translation>Portable Document Format (*.pdf)</translation>
    </message>
    <message>
        <source>PDF import failed.</source>
        <translation>Import af PDF mislykkedes.</translation>
    </message>
    <message>
        <source>Importing page %1 of %2</source>
        <translation>Importerer side %1 af %2</translation>
    </message>
</context>
<context>
    <name>UBIntranetPodcastPublisher</name>
    <message>
        <source>Error while publishing video to intranet (%1)</source>
        <translation>Fejl under udgivelse af video til Intranet (%1)</translation>
    </message>
    <message>
        <source>Publishing to Intranet in progress %1 %</source>
        <translation>Udgivelse til Intranet i gang %1 %</translation>
    </message>
</context>
<context>
    <name>UBIntranetPodcastPublishingDialog</name>
    <message>
        <source>Publish</source>
        <translation>Udgiv</translation>
    </message>
</context>
<context>
    <name>UBKeyboardPalette</name>
    <message>
        <source>Enter</source>
        <translation>Enter</translation>
    </message>
</context>
<context>
    <name>UBMainWindow</name>
    <message>
        <source>Yes</source>
        <translation>Ja</translation>
    </message>
    <message>
        <source>No</source>
        <translation>Nej</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
</context>
<context>
    <name>UBMessagesDialog</name>
    <message>
        <source>Close</source>
        <translation>Luk</translation>
    </message>
</context>
<context>
    <name>UBNetworkAccessManager</name>
    <message>
        <source>&lt;qt&gt;Enter username and password for &quot;%1&quot; at %2&lt;/qt&gt;</source>
        <translation>&lt;qt&gt;Indtast brugernavn og adgangskode &quot;%1&quot; at %2&lt;/qt&gt;</translation>
    </message>
    <message>
        <source>Failed to log to Proxy</source>
        <translation>Kunne ikke logge på Proxy</translation>
    </message>
    <message>
        <source>SSL Errors:

%1

%2

Do you want to ignore these errors for this host?</source>
        <translation>SSL fejl:

%1

%2

Ønsker du at ignorere disse fejl for denne host?</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Ja</translation>
    </message>
    <message>
        <source>No</source>
        <translation>Nej</translation>
    </message>
</context>
<context>
    <name>UBOpenSankoreImporterWidget</name>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">Annuller</translation>
    </message>
    <message>
        <source>Open-Sankore Documents Detected</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open-Sankoré documents are present on your computer. It is possible to import them to OpenBoard by pressing the “Proceed” button to launch the importer application.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show this panel next time</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You can always access the OpenBoard Document Importer through the Preferences panel in the About tab. Warning, if you have already imported your Open-Sankore datas, you might loose your current OpenBoard documents.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Proceed</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBPersistenceManager</name>
    <message>
        <source>(copy)</source>
        <translation>(kopier)</translation>
    </message>
    <message>
        <source>Document Repository Loss</source>
        <translation>Tab af dokumentdepot</translation>
    </message>
    <message>
        <source>OpenBoard has lost access to the document repository &apos;%1&apos;. Unfortunately the application must shut down to avoid data corruption. Latest changes may be lost as well.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Renaming pages (%1/%2)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Retrieving all your documents (found : %1)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBPlatformUtils</name>
    <message>
        <source>English</source>
        <translation>Engelsk</translation>
    </message>
    <message>
        <source>Russian</source>
        <translation>Russisk</translation>
    </message>
    <message>
        <source>German</source>
        <translation>Tysk</translation>
    </message>
    <message>
        <source>French</source>
        <translation>Fransk</translation>
    </message>
    <message>
        <source>Swiss French</source>
        <translation>Schweizisk Fransk</translation>
    </message>
</context>
<context>
    <name>UBPodcastController</name>
    <message>
        <source>Failed to start encoder ...</source>
        <translation>Kunne ikke starte indkoderen ...</translation>
    </message>
    <message>
        <source>No Podcast encoder available ...</source>
        <translation>Der er ingen podcast-indkoder tilgængelig...</translation>
    </message>
    <message>
        <source>Part %1</source>
        <translation>Del %1</translation>
    </message>
    <message>
        <source>on your desktop ...</source>
        <translation>på dit skriveord...</translation>
    </message>
    <message>
        <source>in folder %1</source>
        <translation>i mappe %1</translation>
    </message>
    <message>
        <source>Podcast created %1</source>
        <translation>Podcast oprettet %1</translation>
    </message>
    <message>
        <source>Podcast recording error (%1)</source>
        <translation>Fejl under optagelse af podcast (%1)</translation>
    </message>
    <message>
        <source>Default Audio Input</source>
        <translation>Standard lydinput</translation>
    </message>
    <message>
        <source>No Audio Recording</source>
        <translation>Ingen lydoptagelse</translation>
    </message>
    <message>
        <source>Small</source>
        <translation>Lille</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>Medium</translation>
    </message>
    <message>
        <source>Full</source>
        <translation>Fuld</translation>
    </message>
    <message>
        <source>Publish to Intranet</source>
        <translation>Udgiv til Intranet</translation>
    </message>
    <message>
        <source>Publish to Youtube</source>
        <translation>Udgiv på Youtube</translation>
    </message>
    <message>
        <source>OpenBoard Cast</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBPreferencesController</name>
    <message>
        <source>version: </source>
        <translation>version:</translation>
    </message>
    <message>
        <source>Marker is pressure sensitive</source>
        <translation>Markøren er tryksensitiv</translation>
    </message>
</context>
<context>
    <name>UBProxyLoginDlg</name>
    <message>
        <source>Proxy Login</source>
        <translation type="vanished">Proxy Login</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation type="vanished">Brugernavn:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation type="vanished">Adgangskode:</translation>
    </message>
</context>
<context>
    <name>UBPublicationDlg</name>
    <message>
        <source>Publish document on the web</source>
        <translation type="vanished">Udgiv dokument på web</translation>
    </message>
    <message>
        <source>Title:</source>
        <translation type="vanished">Titel:</translation>
    </message>
    <message>
        <source>Description:</source>
        <translation type="vanished">Beskrivelse:</translation>
    </message>
    <message>
        <source>Publish</source>
        <translation type="vanished">Udgiv</translation>
    </message>
</context>
<context>
    <name>UBSettings</name>
    <message>
        <source>My Movies</source>
        <translation>Mine Film</translation>
    </message>
</context>
<context>
    <name>UBStartupHintsPalette</name>
    <message>
        <source>Visible next time</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBTeacherBarWidget</name>
    <message>
        <source></source>
        <translation></translation>
    </message>
</context>
<context>
    <name>UBThumbnailAdaptor</name>
    <message>
        <source>Generating preview thumbnails ...</source>
        <translation>Genererer forhåndsvisning af miniaturebilleder...</translation>
    </message>
    <message>
        <source>%1 thumbnails generated ...</source>
        <translation>%1 miniaturebilleder genereret...</translation>
    </message>
    <message>
        <source>Loading thumbnail (%1/%2)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBThumbnailTextItem</name>
    <message>
        <source>Page %0</source>
        <translation type="unfinished">Side %0</translation>
    </message>
</context>
<context>
    <name>UBToolsManager</name>
    <message>
        <source>Mask</source>
        <translation>Maske</translation>
    </message>
    <message>
        <source>Ruler</source>
        <translation>Lineal</translation>
    </message>
    <message>
        <source>Compass</source>
        <translation>Kompas</translation>
    </message>
    <message>
        <source>Protractor</source>
        <translation>Vinkelmåler</translation>
    </message>
    <message>
        <source>Triangle</source>
        <translation>Trekant</translation>
    </message>
    <message>
        <source>Magnifier</source>
        <translation>Lup</translation>
    </message>
    <message>
        <source>Cache</source>
        <translation>Cache</translation>
    </message>
    <message>
        <source>Axes</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBTrapFlashController</name>
    <message>
        <source>Whole page</source>
        <translation>Hel side</translation>
    </message>
    <message>
        <source>Web</source>
        <translation>Web</translation>
    </message>
</context>
<context>
    <name>UBUpdateDlg</name>
    <message>
        <source>Document updater</source>
        <translation>Dokument opdateringsværktøj</translation>
    </message>
    <message>
        <source> files require an update.</source>
        <translation> filer kræver en opdatering.</translation>
    </message>
    <message>
        <source>Backup path: </source>
        <translation>Backup path: </translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>Gennemse</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>Opdater</translation>
    </message>
    <message>
        <source>Select a backup folder</source>
        <translation>Vælg en mappe til backup</translation>
    </message>
    <message>
        <source>Files update successful!
Please reboot the application to access the updated documents.</source>
        <translation>Filopdatering gennemført!
Genstart venligst applikationen for at få adgang til de opdaterede dokumenter.</translation>
    </message>
    <message>
        <source>An error occured during the update. The files have not been affected.</source>
        <translation>Der opstod en fejl under opdateringen. Filerne er ikke påvirket af fejlen.</translation>
    </message>
    <message>
        <source>Files update results</source>
        <translation>Resultater af filopdatering</translation>
    </message>
    <message>
        <source>Updating file </source>
        <translation>Opdaterer fil</translation>
    </message>
    <message>
        <source>Please wait the import process will start soon...</source>
        <translation>Vent venligst, import vil snart begynde...</translation>
    </message>
    <message>
        <source>Remind me later</source>
        <translation>Påmind mig senere</translation>
    </message>
</context>
<context>
    <name>UBWebPluginWidget</name>
    <message>
        <source>Loading...</source>
        <translation>Indlæser...</translation>
    </message>
</context>
<context>
    <name>UBWidgetUniboardAPI</name>
    <message>
        <source>%0 called (method=%1, status=%2)</source>
        <translation>%0 kaldt (metode=%1, status=%2)</translation>
    </message>
</context>
<context>
    <name>UBYouTubePublisher</name>
    <message>
        <source>YouTube authentication failed.</source>
        <translation>Godkendelse fra YouTube mislykkedes.</translation>
    </message>
    <message>
        <source>Error while uploading video to YouTube (%1)</source>
        <translation>Fejl under opload af video til YouTube (%1)</translation>
    </message>
    <message>
        <source>Upload to YouTube in progress %1 %</source>
        <translation>Upload til YouTube i gang %1 %</translation>
    </message>
</context>
<context>
    <name>UBYouTubePublishingDialog</name>
    <message>
        <source>Upload</source>
        <translation>Upload</translation>
    </message>
    <message>
        <source>Autos &amp; Vehicles</source>
        <translation>Biler &amp; Køretøjer</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Musik</translation>
    </message>
    <message>
        <source>Pets &amp; Animals</source>
        <translation>Kæledyr &amp; Dyr</translation>
    </message>
    <message>
        <source>Sports</source>
        <translation>Sport</translation>
    </message>
    <message>
        <source>Travel &amp; Events</source>
        <translation>Rejser &amp; Begivenheder</translation>
    </message>
    <message>
        <source>Gaming</source>
        <translation>Spil</translation>
    </message>
    <message>
        <source>Comedy</source>
        <translation>Komedie</translation>
    </message>
    <message>
        <source>People &amp; Blogs</source>
        <translation>Mennesker &amp; Blogs</translation>
    </message>
    <message>
        <source>News &amp; Politics</source>
        <translation>Nyheder &amp; Politik</translation>
    </message>
    <message>
        <source>Entertainment</source>
        <translation>Underholdning</translation>
    </message>
    <message>
        <source>Education</source>
        <translation>Uddannelse</translation>
    </message>
    <message>
        <source>Howto &amp; Style</source>
        <translation>Tips &amp; Stil</translation>
    </message>
    <message>
        <source>Nonprofits &amp; Activism</source>
        <translation>NGO &amp; Aktivisme</translation>
    </message>
    <message>
        <source>Science &amp; Technology</source>
        <translation>Videnskab &amp; Teknologi</translation>
    </message>
</context>
<context>
    <name>UBZoomPalette</name>
    <message>
        <source>%1 x</source>
        <translation>%1 x</translation>
    </message>
</context>
<context>
    <name>WBClearButton</name>
    <message>
        <source>Clear</source>
        <translation>Ryd</translation>
    </message>
</context>
<context>
    <name>WBDownloadItem</name>
    <message>
        <source>Save File</source>
        <translation>Gem fil</translation>
    </message>
    <message>
        <source>Download canceled: %1</source>
        <translation>Download annulleret: %1</translation>
    </message>
    <message>
        <source>Error opening saved file: %1</source>
        <translation>Fejl under åbning af gemt fil: %1</translation>
    </message>
    <message>
        <source>Error saving: %1</source>
        <translation>Fejl under gem: %1</translation>
    </message>
    <message>
        <source>Network Error: %1</source>
        <translation>Netværksfejl: %1</translation>
    </message>
    <message>
        <source>seconds</source>
        <translation>sekunder</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation>minutter</translation>
    </message>
    <message>
        <source>- %4 %5 remaining</source>
        <translation>- %4 %5 tilbage</translation>
    </message>
    <message>
        <source>%1 of %2 (%3/sec) %4</source>
        <translation>%1 af %2 (%3/sek) %4</translation>
    </message>
    <message>
        <source>?</source>
        <comment>unknown file size</comment>
        <translation>?</translation>
    </message>
    <message>
        <source>%1 of %2 - Stopped</source>
        <translation>%1 af %2 - Stoppet</translation>
    </message>
    <message>
        <source>bytes</source>
        <translation>bytes</translation>
    </message>
    <message>
        <source>KB</source>
        <translation>KB</translation>
    </message>
    <message>
        <source>MB</source>
        <translation>MB</translation>
    </message>
</context>
<context>
    <name>WBDownloadManager</name>
    <message>
        <source>1 Download</source>
        <translation>1 Download</translation>
    </message>
    <message>
        <source>%1 Downloads</source>
        <comment>always &gt;= 2</comment>
        <translation>%1 Downloads</translation>
    </message>
</context>
<context>
    <name>WBHistoryModel</name>
    <message>
        <source>Title</source>
        <translation>Titel</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Adresse</translation>
    </message>
</context>
<context>
    <name>WBHistoryTreeModel</name>
    <message>
        <source>Earlier Today</source>
        <translation>Tidligere i dag</translation>
    </message>
    <message>
        <source>%1 items</source>
        <translation>%1 enheder</translation>
    </message>
</context>
<context>
    <name>WBSearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>Søg</translation>
    </message>
</context>
<context>
    <name>WBTabBar</name>
    <message>
        <source>New &amp;Tab</source>
        <translation>Ny &amp;Fane</translation>
    </message>
    <message>
        <source>Clone Tab</source>
        <translation>Klon fane</translation>
    </message>
    <message>
        <source>&amp;Close Tab</source>
        <translation>&amp;Luk fane</translation>
    </message>
    <message>
        <source>Close &amp;Other Tabs</source>
        <translation>Luk &amp;Andre faner</translation>
    </message>
    <message>
        <source>Reload Tab</source>
        <translation>Genindlæs fane</translation>
    </message>
    <message>
        <source>Reload All Tabs</source>
        <translation>Genindlæs alle faner</translation>
    </message>
</context>
<context>
    <name>WBTabWidget</name>
    <message>
        <source>Recently Closed Tabs</source>
        <translation>Senest lukkede faner</translation>
    </message>
    <message>
        <source>(Untitled)</source>
        <translation>(Uden titel)</translation>
    </message>
</context>
<context>
    <name>WBToolbarSearch</name>
    <message>
        <source>Search</source>
        <translation>Søg</translation>
    </message>
    <message>
        <source>No Recent Searches</source>
        <translation>Ingen seneste søgninger</translation>
    </message>
    <message>
        <source>Recent Searches</source>
        <translation>Seneste søgninger</translation>
    </message>
    <message>
        <source>Clear Recent Searches</source>
        <translation>Ryd seneste søgninger</translation>
    </message>
</context>
<context>
    <name>WBWebPage</name>
    <message>
        <source>Download</source>
        <translation>Download</translation>
    </message>
    <message>
        <source>Add to Current Document</source>
        <translation>Tilføj til aktuelt dokument</translation>
    </message>
    <message>
        <source>PDF</source>
        <translation>PDF</translation>
    </message>
    <message>
        <source>Error loading page: %1</source>
        <translation>Fejl under indlæsning af side: %1</translation>
    </message>
    <message>
        <source>Download PDF Document: would you prefer to download the PDF file or add it to the current OpenBoard document?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>WBWebView</name>
    <message>
        <source>Open in New Tab</source>
        <translation>Åbn i ny fane</translation>
    </message>
</context>
<context>
    <name>XPDFRenderer</name>
    <message>
        <source>Processing...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>YouTubePublishingDialog</name>
    <message>
        <source>Publish Podcast to YouTube</source>
        <translation>Udgiv podcast på YouTube</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Titel</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Beskrivelse</translation>
    </message>
    <message>
        <source>Keywords</source>
        <translation>Søgeord</translation>
    </message>
    <message>
        <source>Category</source>
        <translation>Kategori</translation>
    </message>
    <message>
        <source>YouTube Username</source>
        <translation>YouTube brugernavn</translation>
    </message>
    <message>
        <source>YouTube Password</source>
        <translation>YouTube adgangskode</translation>
    </message>
    <message>
        <source>OpenBoard</source>
        <translation type="unfinished">OpenBoard</translation>
    </message>
    <message>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;MS Shell Dlg 2&apos;; font-size:8.25pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Lucida Grande&apos;; font-size:10pt;&quot;&gt;By clicking &apos;Upload,&apos; you certify that you own all rights to the content or that you are authorized by the owner to make the content publicly available on YouTube, and that it otherwise complies with the YouTube Terms of Service located at &lt;/span&gt;&lt;a href=&quot;http://www.youtube.com/t/terms&quot;&gt;&lt;span style=&quot; font-family:&apos;Lucida Grande&apos;; font-size:10pt; text-decoration: underline; color:#0000ff;&quot;&gt;http://www.youtube.com/t/terms&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Restore credentials on reboot</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>brushProperties</name>
    <message>
        <source>On Light Background</source>
        <translation>På lys baggrund</translation>
    </message>
    <message>
        <source>On Dark Background</source>
        <translation>På mørk baggrund</translation>
    </message>
    <message>
        <source>Opacity</source>
        <translation>Gennemsigtighed</translation>
    </message>
    <message>
        <source>Line Width</source>
        <translation>Linjebredde</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>Medium</translation>
    </message>
    <message>
        <source>Strong</source>
        <translation>Stærk</translation>
    </message>
    <message>
        <source>Fine</source>
        <translation>Fin</translation>
    </message>
    <message>
        <source>Pen is Pressure Sensitive</source>
        <translation>Pen er tryksensitiv</translation>
    </message>
    <message>
        <source>Show preview circle from</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>px</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>capturePublishingDialog</name>
    <message>
        <source>Dialog</source>
        <translation>Dialog</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Titel</translation>
    </message>
    <message>
        <source>E-mail</source>
        <translation>E-mail</translation>
    </message>
    <message>
        <source>Author</source>
        <translation>Forfatter</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Beskrivelse</translation>
    </message>
</context>
<context>
    <name>documentPublishingDialog</name>
    <message>
        <source>Dialog</source>
        <translation type="obsolete">Dialog</translation>
    </message>
    <message>
        <source>Title</source>
        <translation type="obsolete">Titel</translation>
    </message>
    <message>
        <source>E-mail</source>
        <translation type="obsolete">E-mail</translation>
    </message>
    <message>
        <source>Author</source>
        <translation type="obsolete">Forfatter</translation>
    </message>
    <message>
        <source>Description</source>
        <translation type="obsolete">Beskrivelse</translation>
    </message>
</context>
<context>
    <name>documents</name>
    <message>
        <source>OpenBoard Documents</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Creation date</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Update date</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Alphabetical order</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sort Order</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>preferencesDialog</name>
    <message>
        <source>Preferences</source>
        <translation>Indstillinger</translation>
    </message>
    <message>
        <source>version : …</source>
        <translation>version: ...</translation>
    </message>
    <message>
        <source>Default Settings</source>
        <translation>Standardindstillinger</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Luk</translation>
    </message>
    <message>
        <source>Display</source>
        <translation>Display</translation>
    </message>
    <message>
        <source>Internet</source>
        <translation>Internet</translation>
    </message>
    <message>
        <source>Show Page with External Browser</source>
        <translation>Vis side med en ekstern browser</translation>
    </message>
    <message>
        <source>Home Page:</source>
        <translation>Hjem-side:</translation>
    </message>
    <message>
        <source>Virtual Keyboard</source>
        <translation>Virtuelt tastatur</translation>
    </message>
    <message>
        <source>Keyboard button size:</source>
        <translation type="vanished">Størrelse på tastaturknapper:</translation>
    </message>
    <message>
        <source>Toolbar</source>
        <translation>Værktøjslinje</translation>
    </message>
    <message>
        <source>Positioned at the Top (recommended for tablets)</source>
        <translation>Placeret i toppen (anbefales for tablets)</translation>
    </message>
    <message>
        <source>Positioned at the Bottom (recommended for white boards)</source>
        <translation>Placeret i bunden (anbefalet for white boards)</translation>
    </message>
    <message>
        <source>Display Text Under Button</source>
        <translation>Vis tekst under knap</translation>
    </message>
    <message>
        <source>Stylus Palette</source>
        <translation>Penpalette</translation>
    </message>
    <message>
        <source>Horizontal</source>
        <translation>Horisontal</translation>
    </message>
    <message>
        <source>Vertical</source>
        <translation>Vertikal</translation>
    </message>
    <message>
        <source>Pen</source>
        <translation>Pen</translation>
    </message>
    <message>
        <source>Marker</source>
        <translation>Markør</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Om</translation>
    </message>
    <message>
        <source>Software Update</source>
        <translation>Softwareopdatering</translation>
    </message>
    <message>
        <source>Check software update at launch</source>
        <translation>Kontroller for softwareopdateringer ved opstart</translation>
    </message>
    <message>
        <source>Licences</source>
        <translation>Licenser</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Netværk</translation>
    </message>
    <message>
        <source>Show internal web page content on secondary screen or projector</source>
        <translation>Vis indhold fra intern webside på sekundær skærm eller projektor</translation>
    </message>
    <message>
        <source>Multi display</source>
        <translation>Multivisning</translation>
    </message>
    <message>
        <source>Swap control display and view display</source>
        <translation>Skift mellem kontrolvisning og almindelig visning</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>Tilstand</translation>
    </message>
    <message>
        <source>Mode to start in:</source>
        <translation>Starttilstand:</translation>
    </message>
    <message>
        <source>Board</source>
        <translation>Tavle</translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation>Skrivebord</translation>
    </message>
    <message>
        <source>Proxy User:</source>
        <translation>Proxy-bruger:</translation>
    </message>
    <message>
        <source>Pass:</source>
        <translation>Adgangskode:</translation>
    </message>
    <message>
        <source>Credits</source>
        <translation>Anerkendelse</translation>
    </message>
    <message>
        <source>On Dark Background</source>
        <translation type="unfinished">På mørk baggrund</translation>
    </message>
    <message>
        <source>Opacity</source>
        <translation type="unfinished">Gennemsigtighed</translation>
    </message>
    <message>
        <source>On Light Background</source>
        <translation type="unfinished">På lys baggrund</translation>
    </message>
    <message>
        <source>Swap first and second view displays</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Built-in virtual keyboard button size:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use system keyboard (recommended)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Grid</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open-Sankoré Importer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Check if Open-Sankoré data could be imported at launch</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Documents Mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Display date column on alphabetical sort</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Empty trash for documents older than</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>days</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>PDF Rendering</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Improve zoom execution time (can slightly affect rendering quality)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>trapFlashDialog</name>
    <message>
        <source>Trap flash</source>
        <translation>Opsaml flash</translation>
    </message>
    <message>
        <source>Select a flash to trap</source>
        <translation type="vanished">Vælg en flash der skal opsamles</translation>
    </message>
    <message>
        <source>about:blank</source>
        <translation>Om:bland</translation>
    </message>
    <message>
        <source>Application name</source>
        <translation>Navn på applikation</translation>
    </message>
    <message>
        <source>Create Application</source>
        <translation>Opret applikation</translation>
    </message>
    <message>
        <source>Select a content to capture</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
